@@ -16,12 +16,14 @@ _set_mpl_backend()
 # This is the only place the version is specified and 
 # used in both setup.py and docs/conf.py to set the 
 # version of ggplot.
-__version__ = '0.5.5'
+__version__ = '0.5.8'
 
 from .qplot import qplot
 from .ggplot import ggplot
 from .components import aes
+from .coords import *
 from .geoms import *
+from .stats import *
 from .scales import *
 from .themes import *
 from .utils import *
