@@ -1,3 +1,5 @@
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
 # geoms
 from .geom_abline import geom_abline
 from .geom_area import geom_area
@@ -8,16 +10,15 @@ from .geom_hline import geom_hline
 from .geom_jitter import geom_jitter
 from .geom_line import geom_line
 from .geom_now_its_art import geom_now_its_art
+from .geom_path import geom_path
 from .geom_point import geom_point
 from .geom_rect import geom_rect
+from .geom_smooth import geom_smooth
 from .geom_step import geom_step
 from .geom_text import geom_text
 from .geom_tile import geom_tile
 from .geom_vline import geom_vline
-# stats
-from .stat_bin2d import stat_bin2d
-from .stat_function import stat_function
-from .stat_smooth import stat_smooth
+
 # misc
 from .facet_grid import facet_grid
 from .facet_wrap import facet_wrap
@@ -25,9 +26,10 @@ from .chart_components import *
 
 __facet__ = ['facet_grid', 'facet_wrap']
 __geoms__ = ['geom_abline', 'geom_area', 'geom_bar', 'geom_density',
-             'geom_histogram', 'geom_hline', 'geom_jitter', 'geom_line', 
-             'geom_now_its_art', 'geom_point', 'geom_rect', 'geom_step',
-             'geom_text', 'geom_tile', 'geom_vline']
-__stats__ = ['stat_bin2d', 'stat_smooth']
+             'geom_histogram', 'geom_hline', 'geom_jitter', 'geom_line',
+             'geom_now_its_art', 'geom_path', 'geom_point', 'geom_rect',
+             'geom_step', 'geom_smooth', 'geom_text', 'geom_tile',
+             'geom_vline']
 __components__ = ['ylab', 'xlab', 'ylim', 'xlim', 'labs', 'ggtitle']
-__ALL__ = __geoms__ + __facet__ + __stats__ + __components__
+__all__ = __geoms__ + __facet__ + __components__
+__all__ = [str(u) for u in __all__]
